==> haskell-filelock-0.1.1.7-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filelock
version:              0.1.1.7
visibility:           public
id:                   filelock-0.1.1.7-JuTUL0KxDQZ6hqcLIYBTiE
key:                  filelock-0.1.1.7-JuTUL0KxDQZ6hqcLIYBTiE
license:              LicenseRef-PublicDomain
maintainer:           Andreas Abel
author:               Takano Akio
homepage:             http://github.com/haskell-pkg-janitors/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  1d3335977aea213d834b468f0c3a9a4c
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filelock-0.1.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filelock-0.1.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filelock-0.1.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filelock
hs-libraries:         HSfilelock-0.1.1.7-JuTUL0KxDQZ6hqcLIYBTiE
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filelock-0.1.1.7-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filelock
version:              0.1.1.7
visibility:           public
id:                   filelock-0.1.1.7-K9NDPidNJ6776qpzG2s0tE
key:                  filelock-0.1.1.7-K9NDPidNJ6776qpzG2s0tE
license:              LicenseRef-PublicDomain
maintainer:           Andreas Abel
author:               Takano Akio
homepage:             http://github.com/haskell-pkg-janitors/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  04dc4e5a2e7c7a3418e52fbf0db18efa
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filelock-0.1.1.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filelock-0.1.1.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filelock-0.1.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filelock
hs-libraries:         HSfilelock-0.1.1.7-K9NDPidNJ6776qpzG2s0tE
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
